use poise::{serenity_prelude::CreateEmbed, CreateReply};
use serde::{Deserialize, Serialize};

use crate::{
    consts::THEME_COLOR,
    models::CtxData,
    utils::{Extract, Recordable},
    Context, Error,
};

#[derive(Serialize, Deserialize, Extract)]
pub struct Options;

impl Recordable for Options {
    async fn run(self, ctx: Context<'_>) -> Result<(), Error> {
        let mut user_data = ctx.author_data().await?;
        user_data.allowed_dm = false;
        user_data.commit_changes(&ctx.data().database).await;

        ctx.send(
            CreateReply::default().ephemeral(true).embed(
                CreateEmbed::new()
                    .title("DMs blocked")
                    .description(concat!(
                        "You can still set DM reminders for yourself or for users with",
                        " DMs enabled."
                    ))
                    .color(*THEME_COLOR),
            ),
        )
        .await?;

        Ok(())
    }
}

/// Block other users from setting reminders in your direct messages
#[poise::command(slash_command, rename = "block", identifying_name = "unset_allowed_dm")]
pub async fn unset(ctx: Context<'_>) -> Result<(), Error> {
    (Options {}).run(ctx).await
}
