use serde::{Deserialize, Serialize};

use crate::{
    commands::todo::show_todo_page,
    utils::{Extract, Recordable},
    Context, Error,
};

#[derive(Serialize, Deserialize, Extract)]
pub struct Options;

impl Recordable for Options {
    async fn run(self, ctx: Context<'_>) -> Result<(), Error> {
        let values = sqlx::query!(
            "
            SELECT todos.id, value FROM todos
            WHERE user_id = ?
            ",
            ctx.author().id.get(),
        )
        .fetch_all(&ctx.data().database)
        .await
        .unwrap()
        .iter()
        .map(|row| (row.id as usize, row.value.clone()))
        .collect::<Vec<(usize, String)>>();

        let resp = show_todo_page(&values, 0, Some(ctx.author().id.get()), None, None);

        ctx.send(resp).await?;

        Ok(())
    }
}

/// View and remove from your personal todo list
#[poise::command(slash_command, rename = "view", identifying_name = "todo_user_view")]
pub async fn view(ctx: Context<'_>) -> Result<(), Error> {
    (Options {}).run(ctx).await
}
